#!/usr/bin/env python
"""Tests for `deluge_cmd` package."""

# from unittest import mock, skip
# from deluge_cmd import deluge_dls
# from collections import namedtuple


# args_tuple = namedtuple('args', 'type root pattern debug')
# @mock.patch('deluge_cmd.deluge_dls.list_deluge_fs', return_value=[])
# def test_command_line_interface(mocked):
#     """Test the CLI."""
#     args = args_tuple('a', '.', '*', '')
#     deluge_dls.handle_args(args)
#     assert mocked.call_count == 1
